==> customer-link-project-api-0.0.71-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app89569/vo/SendMoneyRequestRow.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app89569.vo;

public class SendMoneyRequestRow {
    /**
     * 用户id
     * uid
     */
    private String userId;
    /**
     * 兑吧订单号
     */
    private String orderNo;
    /**
     * 奖品名称
     */
    private String prizeName;
    /**
     * 金额 单位：分
     */
    private Integer amount;

    /**
     * 项目id
     */
    private String activityId;

    /**
     * 项目名称
     */
    private String activityName;

    /**
     * 1(奖券)
     * 目前只有这一个默认传1就行，后边如果有其他活动发红包再进行类型定义
     */
    private String activityType;

    /**
     * 备注
     */
    private String remark = "";

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}

==> customer-link-project-api-1.1.5-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app89569/vo/SendMoneyRequestRow.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app89569.vo;

public class SendMoneyRequestRow {
    /**
     * 用户id
     * uid
     */
    private String userId;
    /**
     * 兑吧订单号
     */
    private String orderNo;
    /**
     * 奖品名称
     */
    private String prizeName;
    /**
     * 金额 单位：分
     */
    private Integer amount;

    /**
     * 项目id
     */
    private String activityId;

    /**
     * 项目名称
     */
    private String activityName;

    /**
     * 1(奖券)
     * 目前只有这一个默认传1就行，后边如果有其他活动发红包再进行类型定义
     */
    private String activityType;

    /**
     * 备注
     */
    private String remark = "";

    /**
     * 渠道
     * 口味王=kww
     * 合成天下=hctx
     */
    private String channel = "kww";

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }
}
